/*-----------------------------------------------------------------------
/  Low level disk interface modlue include file  R0.05   (C)ChaN, 2007
/-----------------------------------------------------------------------*/

/**************************************************************************
Modified and optimized for the CodeVisionAVR V2.04.4+ C Compiler
by Pavel Haiduc, HP InfoTech s.r.l. (C) 2009

V1.0 July 2009
**************************************************************************/

#ifndef __SDCARD_INCLUDED__
#define __SDCARD_INCLUDED__

/* Status of Disk Functions */
typedef unsigned char DSTATUS;

/* Results of Disk Functions */
typedef enum {
	RES_OK = 0,		/* 0: Successful */
	RES_ERROR,		/* 1: R/W Error */
	RES_WRPRT,		/* 2: Write Protected */
	RES_NOTRDY,		/* 3: Not Ready */
	RES_PARERR		/* 4: Invalid Parameter */
} DRESULT;

/*---------------------------------------*/
/* Prototypes for disk control functions */

DSTATUS disk_initialize (unsigned char drv);
DSTATUS disk_status (unsigned char drv);
DRESULT disk_read (unsigned char drv, unsigned char* buff, unsigned long sector, unsigned char count);
DRESULT disk_write (unsigned char drv, const unsigned char* buff, unsigned long sector, unsigned char count);
DRESULT disk_ioctl (unsigned char drv, unsigned char ctrl, void* buff);
void disk_timerproc (void);

/* Disk Status Flag Bits (DSTATUS) */
#define STA_NOINIT		0x01	/* Drive not initialized */
#define STA_NODISK		0x02	/* No medium in the drive */
#define STA_PROTECT		0x04	/* Write protected */

/* Command codes for disk_ioctrl() */
/* Generic commands */
#define CTRL_SYNC			0	/* Mandatory for write functions */
#define GET_SECTOR_COUNT	     1	/* Mandatory for only f_mkfs() */
#define GET_SECTOR_SIZE		2
#define GET_BLOCK_SIZE		3	/* Mandatory for only f_mkfs() */

/* MMC/SDC commands */
#define MMC_GET_TYPE		10
#define MMC_GET_CSD			11
#define MMC_GET_CID			12
#define MMC_GET_OCR			13
#define MMC_GET_SDSTAT		14

/* Card type flags (CardType) */
#define CT_MMC				0x01
#define CT_SD1				0x02
#define CT_SD2				0x04
#define CT_SDC				(CT_SD1|CT_SD2)
#define CT_BLOCK			0x08

#pragma library sdcard.lib

#endif
